@@ -565,8 +565,10 @@ ALL_DIMENSIONS = {
     "video",
     "playlist",
     "channel",
+    "creatorContentType",
     "country",
     "province",
+    "city",
     "day",
     "month",
     "insightPlaybackLocationType",
@@ -595,6 +597,7 @@ VALID_FILTER_OPTIONS = {
     "group": (),
     "country": COUNTRIES,
     "province": SUBDIVISIONS,
+    "city": (),
     "continent": (
         "002",
         "019",
