@@ -28,18 +28,20 @@
 
 from __future__ import annotations
 
-__all__ = ("can_use", "requires", "warn", "warn_on_call")
+__all__ = ("can_use", "requires", "process_path")
 
 import logging
 import typing as t
-import warnings
 from functools import wraps
+from pathlib import Path
 
 from pkg_resources import working_set
 
 from analytix.errors import MissingOptionalComponents
 
 if t.TYPE_CHECKING:
+    from analytix.types import PathLikeT
+
     _FuncT = t.Callable[..., t.Any]
 
 _log = logging.getLogger(__name__)
@@ -67,20 +69,14 @@ def requires(*packages: str) -> t.Callable[[_FuncT], _FuncT]:
     return decorator
 
 
-def warn(message: str) -> None:
-    if _log.hasHandlers() and _log.getEffectiveLevel() <= 30:
-        _log.warning(message)
-    else:
-        warnings.warn(message)
+def process_path(path: PathLikeT, extension: str, overwrite: bool) -> Path:
+    if not isinstance(path, Path):
+        path = Path(path)
 
+    if path.suffix != extension:
+        path = Path(path.name + extension)
 
-def warn_on_call(message: str) -> t.Callable[[_FuncT], _FuncT]:
-    def decorator(func: _FuncT) -> _FuncT:
-        @wraps(func)
-        def wrapper(*args: t.Any, **kwargs: t.Any) -> t.Any:
-            warn(message)
-            return func(*args, **kwargs)
+    if not overwrite and path.is_file():
+        raise FileExistsError("file already exists and `overwrite` is set to False")
 
-        return wrapper
-
-    return decorator
+    return path
